@@ -1,4 +1,4 @@
-/* Work around unlinkat bugs on Solaris 9.
+/* Work around unlinkat bugs on Solaris 9 and Hurd.
 
    Copyright (C) 2009-2011 Free Software Foundation, Inc.
 
@@ -26,6 +26,8 @@
 #include <string.h>
 #include <sys/stat.h>
 
+#include <stdlib.h>
+
 #include "dosname.h"
 #include "openat.h"
 
@@ -34,7 +36,8 @@
 # undef unlinkat
 
 /* unlinkat without AT_REMOVEDIR does not honor trailing / on Solaris
-   9.  Solve it in a similar manner to unlink.  */
+   9.  Solve it in a similar manner to unlink.  Hurd has the same
+   issue. */
 
 int
 rpl_unlinkat (int fd, char const *name, int flag)
