@@ -1,5 +1,5 @@
 /* truncate -- truncate or extend the length of files.
-   Copyright (C) 2008-2010 Free Software Foundation, Inc.
+   Copyright (C) 2008-2011 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -27,8 +27,8 @@
 
 #include "system.h"
 #include "error.h"
-#include "posixver.h"
 #include "quote.h"
+#include "stat-size.h"
 #include "xstrtol.h"
 
 /* The official name of this program (e.g., no `g' prefix).  */
