@@ -1,7 +1,7 @@
 package CuTmpdir;
 # create, then chdir into a temporary sub-directory
 
-# Copyright (C) 2007-2009 Free Software Foundation, Inc.
+# Copyright (C) 2007-2011 Free Software Foundation, Inc.
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -49,16 +49,9 @@ sub chmod_tree
   defined $dir
     or return;
 
-  if (chdir $dir)
-    {
-      # Perform the equivalent of find . -type d -print0|xargs -0 chmod -R 700.
-      my $options = {untaint => 1, wanted => \&chmod_1};
-      find ($options, '.');
-    }
-  else
-    {
-      warn "$ME: failed to chdir to $dir: $!\n";
-    }
+  # Perform the equivalent of find "$dir" -type d -print0|xargs -0 chmod -R 700.
+  my $options = {untaint => 1, wanted => \&chmod_1};
+  find ($options, $dir);
 }
 
 sub import {
@@ -85,10 +78,10 @@ sub import {
     my ($sig) = @_;
     if ($$ == $original_pid and defined $dir)
       {
-	chmod_tree;
-	# Older versions of File::Temp lack this method.
-	exists &File::Temp::cleanup
-	  and &File::Temp::cleanup;
+        chmod_tree;
+        # Older versions of File::Temp lack this method.
+        exists &File::Temp::cleanup
+          and &File::Temp::cleanup;
       }
     $SIG{$sig} = 'DEFAULT';
     kill $sig, $$;
@@ -105,6 +98,11 @@ sub import {
 }
 
 END {
+  # Move cwd out of the directory we're about to remove.
+  # This is required on some systems, and by some versions of File::Temp.
+  chdir '..'
+    or warn "$ME: failed to chdir to .. from $dir: $!\n";
+
   my $saved_errno = $?;
   chmod_tree;
   $? = $saved_errno;
